==> law-centres-jamstack-1.0.34.tgz: package/src/utilities/contentful/renderRichText.js <==
import React from 'react'

import { BLOCKS, INLINES } from '@contentful/rich-text-types'
import { renderComponent } from './renderComponent'
import ReactPlayer from 'react-player/lazy'

import { SmallIconRight } from 'law-centres-design-system'

import {
  Heading,
  Text,
  Image,
  Link,
  Button,
  Container,
  OrderedList,
  UnorderedList,
  ListItem,
  Box,
} from '@chakra-ui/react'

// Can handle richtext from either the GraphQL or Rest APIs
// if using GraphQL, you must also pass in the links in order
// to resolve linked content / associations

const resolveEntry = (node, links) => {
  if (links) {
    return links.entries.block.find(
      (i) => i !== null && i.sys.id === node.data.target.sys.id
    )
  } else {
    return node.data.target
  }
}

const renderRichText = ({
  context = 'light',
  graphLinks = null,
  ContentTypes = ContentTypes,
}) => ({
  renderText: (text) =>
    text.split('\n\n').flatMap((text, i) => [
      i > 0 && (
        <>
          <br />
          <br />
        </>
      ),
      text,
    ]),
  renderNode: {
    [BLOCKS.OL_LIST]: (node, children) => (
      <OrderedList maxWidth="550px" lineHeight="1.8" mb="6">
        {children}
      </OrderedList>
    ),
    [BLOCKS.UL_LIST]: (node, children) => (
      <UnorderedList lineHeight="1.8" mb="6">
        {children}
      </UnorderedList>
    ),
    [BLOCKS.LIST_ITEM]: (node, children) => {
      return <ListItem>{children}</ListItem>
    },
    [BLOCKS.HEADING_1]: (node, children) => (
      <Heading as="h1" variant="h1" mb="5">
        {children}
      </Heading>
    ),
    [BLOCKS.HEADING_2]: (node, children) => (
      <Heading as="h2" variant="h2" mb="6" pt="2">
        {children}
      </Heading>
    ),
    [BLOCKS.HEADING_3]: (node, children) => (
      <Heading as="h3" variant="h3" mb="6" pt="2">
        {children}
      </Heading>
    ),
    [BLOCKS.HEADING_4]: (node, children) => (
      <Heading as="h4" variant="h4" mb="5" pt="2">
        {children}
      </Heading>
    ),
    [BLOCKS.HEADING_5]: (node, children) => (
      <Heading as="h5" variant="h5" mb="5" pt="2">
        {children}
      </Heading>
    ),
    [BLOCKS.HEADING_6]: (node, children) => (
      <Heading as="h6" variant="h5" mb="5" pt="2">
        {children}
      </Heading>
    ),
    [BLOCKS.PARAGRAPH]: (node, children) => <Text mb="5">{children}</Text>,
    // eslint-disable-next-line
    [BLOCKS.EMBEDDED_ENTRY]: (node, children) => {
      let entry = resolveEntry(node, graphLinks)

      if (!entry) return <></>

      return (
        <Box key={node.data.target.sys.id}>
          {renderComponent(entry, context)}
        </Box>
      )
    },
    // eslint-disable-next-line
    [BLOCKS.EMBEDDED_ASSET]: (node, children) => {
      let asset = resolveEntry(node, graphLinks)

      return (
        <>
          {asset?.fields && (
            <>
              {asset.fields.file?.contentType.includes('image') && (
                <Image mb="5" mt="2" alt={asset.title} src={asset.url} />
              )}
              {ReactPlayer.canPlay(asset.fields.file?.url) && (
                <Box pb="5">
                  <ReactPlayer
                    controls={true}
                    config={{
                      file: {
                        attributes: {
                          controlsList: 'nodownload',
                        },
                      },
                    }}
                    height={
                      asset.fields.file?.contentType.includes('video')
                        ? '360px'
                        : '50px'
                    }
                    light={
                      asset.fields.file?.contentType.includes('video')
                        ? '/images/assets/placeholder.jpg'
                        : null
                    }
                    url={asset.fields.file?.url}
                  />
                </Box>
              )}
              {!asset.fields.file?.contentType.includes('image') &&
                !ReactPlayer.canPlay(asset.fields.file?.url) && (
                  <Button
                    as="a"
                    target="_blank"
                    variant="link"
                    colorScheme="green"
                    color="green.500"
                    href={asset.fields.file?.url}
                    mb="5"
                  >
                    {asset.fields.title}
                  </Button>
                )}
            </>
          )}
        </>
      )
    },
    [INLINES.HYPERLINK]: (node, children) => {
      return (
        <>
          {ReactPlayer.canPlay(node.data.uri) && (
            <Container py="5">
              <ReactPlayer controls={true} url={node.data.uri} />
            </Container>
          )}
          {node.data.uri.startsWith('#') ? (
            <Link
              target="_blank"
              href={node.data.uri}
              textDecoration="underline"
              display="flex"
              onClick={(e) => {
                e.preventDefault()
                let heading = Array.from(
                  document.querySelectorAll('h2, h3, h4, h5') // eslint-disable-line
                ).find(
                  (el) => el.textContent === node.data.uri.replace('#', '')
                )
                if (heading) heading.scrollIntoView({ behavior: 'smooth' })
              }}
            >
              <SmallIconRight />
              <Text
                as="span"
                fontWeight="bold"
                maxWidth="25ch"
                pl="1rem"
                mt="-6px"
              >
                {children}
              </Text>
            </Link>
          ) : (
            <Link
              target="_blank"
              href={node.data.uri}
              textDecoration="underline"
              display="flex"
            >
              <SmallIconRight />
              <Text
                as="span"
                fontWeight="bold"
                maxWidth="25ch"
                pl="1rem"
                mt="-6px"
              >
                {children}
              </Text>
            </Link>
          )}
        </>
      )
    },
    [INLINES.ASSET_HYPERLINK]: (node, children) => {
      let asset = resolveEntry(node, graphLinks)

      return (
        <>
          {asset?.fields && (
            <Text as="span">
              <Link href={asset.fields.url} size="md" target="_blank">
                {children}
              </Link>
            </Text>
          )}
        </>
      )
    },
    [INLINES.ENTRY_HYPERLINK]: (node, children) => {
      let entry = resolveEntry(node, graphLinks)

      const contentType = entry.sys?.contentType?.sys?.id
      const linkSlug = entry.fields?.slug

      if (contentType === 'pageSimple') {
        return (
          <Link
            href={linkSlug === 'news' ? '/news' : `/news/${linkSlug}`}
            textDecoration="underline"
            display="flex"
          >
            <SmallIconRight />
            <Text
              as="span"
              fontWeight="bold"
              maxWidth="25ch"
              pl="1rem"
              mt="-6px"
            >
              {children}
            </Text>
          </Link>
        )
      }

      if (contentType === !'pageSimple') {
        return (
          <Link href={`/${linkSlug}`} textDecoration="underline" display="flex">
            <SmallIconRight />
            <Text
              as="span"
              fontWeight="bold"
              maxWidth="25ch"
              pl="1rem"
              mt="-6px"
            >
              {children}
            </Text>
          </Link>
        )
      }
    },
  },
})

export default renderRichText

==> law-centres-jamstack-1.0.50.tgz: package/src/utilities/contentful/renderRichText.js <==
import React from 'react'

import { BLOCKS, INLINES } from '@contentful/rich-text-types'
import { renderComponent } from './renderComponent'

import {
  Heading,
  Image,
  Button,
  Container,
  OrderedList,
  UnorderedList,
  ListItem,
  Box,
  Text,
} from '@chakra-ui/react'

// Can handle richtext from either the GraphQL or Rest APIs
// if using GraphQL, you must also pass in the links in order
// to resolve linked content / associations

const resolveEntry = (node, links) => {
  if (links) {
    return links.entries.block.find(
      (i) => i !== null && i.sys.id === node.data.target.sys.id
    )
  } else {
    return node.data.target
  }
}

const renderRichText = ({
  context = 'light',
  graphLinks = null,
  ContentTypes = ContentTypes,
}) => ({
  renderText: (text) =>
    text.split('\n\n').flatMap((text, i) => [
      i > 0 && (
        <>
          <br />
          <br />
        </>
      ),
      text,
    ]),
  renderNode: {
    [BLOCKS.OL_LIST]: (node, children) => (
      <OrderedList maxWidth="550px" lineHeight="1.8" mb="6">
        {children}
      </OrderedList>
    ),
    [BLOCKS.UL_LIST]: (node, children) => (
      <UnorderedList lineHeight="1.8" mb="6">
        {children}
      </UnorderedList>
    ),
    [BLOCKS.LIST_ITEM]: (node, children) => {
      return <ListItem>{children}</ListItem>
    },
    [BLOCKS.HEADING_1]: (node, children) => (
      <Heading as="h1" variant="h1" mb="5">
        {children}
      </Heading>
    ),
    [BLOCKS.HEADING_2]: (node, children) => (
      <Heading
        as="h2"
        fontSize="50px"
        fontFamily="Anek Latin"
        fontStyle="normal"
        fontWeight="medium"
        lineHeight="54px"
        mb="6"
        pt="2"
      >
        {children}
      </Heading>
    ),
    [BLOCKS.HEADING_3]: (node, children) => (
      <Heading
        as="h3"
        fontSize="46px"
        fontFamily="Anek Latin"
        fontStyle="normal"
        fontWeight={600}
        lineHeight="50px"
        mb="6"
        pt="2"
      >
        {children}
      </Heading>
    ),
    [BLOCKS.HEADING_4]: (node, children) => (
      <Heading
        as="h4"
        fontSize="40px"
        fontFamily="Anek Latin"
        fontStyle="normal"
        fontWeight={500}
        lineHeight="40px"
        letterSpacing="-0.8px"
        mb="5"
        pt="2"
      >
        {children}
      </Heading>
    ),
    [BLOCKS.HEADING_5]: (node, children) => (
      <Heading
        as="h5"
        fontSize="30px"
        fontFamily="Anek Latin"
        fontStyle="normal"
        fontWeight={500}
        lineHeight="36px"
        letterSpacing="0.9px"
        mb="5"
        pt="2"
      >
        {children}
      </Heading>
    ),
    [BLOCKS.HEADING_6]: (node, children) => (
      <Heading
        as="h6"
        fontSize="22px"
        fontFamily="Roboto Slab"
        fontStyle="normal"
        fontWeight={400}
        lineHeight="30px"
        letterSpacing="0.22px"
        pt="2"
      >
        {children}
      </Heading>
    ),
    [BLOCKS.PARAGRAPH]: (node, children) => <Text mb={4}>{children}</Text>,
    // eslint-disable-next-line
    [BLOCKS.EMBEDDED_ENTRY]: (node, children) => {
      let entry = resolveEntry(node, graphLinks)

      if (!entry) return <></>

      return (
        <Box key={node.data.target.sys.id}>
          {renderComponent(entry, context)}
        </Box>
      )
    },
    // eslint-disable-next-line
    [BLOCKS.EMBEDDED_ASSET]: (node, children) => {
      let asset = resolveEntry(node, graphLinks)

      return (
        <>
          {asset?.fields && (
            <>
              {asset.fields.file?.contentType.includes('image') && (
                <Image mb="5" mt="2" alt={asset.title} src={asset.url} />
              )}
              {!asset.fields.file?.contentType.includes('image') &&
                (
                  <Button
                    as="a"
                    variant="link"
                    colorScheme="green"
                    color="green.500"
                    href={asset.fields.file?.url}
                    mb="5"
                  >
                    {asset.fields.title}
                  </Button>
                )}
            </>
          )}
        </>
      )
    },
    [INLINES.HYPERLINK]: (node, children) => {
      return (
        <>
          {node.data.uri.startsWith('#') ? (
            <a
              href={node.data.uri}
              textDecoration="underline"
              display="flex"
              onClick={(e) => {
                e.preventDefault()
                let heading = Array.from(
                  document.querySelectorAll('h2, h3, h4, h5') // eslint-disable-line
                ).find(
                  (el) => el.textContent === node.data.uri.replace('#', '')
                )
                if (heading) heading.scrollIntoView({ behavior: 'smooth' })
              }}
            >
              {children}
            </a>
          ) : (
            <a href={node.data.uri} rel="noreferrer">
              {children}
            </a>
          )}
        </>
      )
    },
    [INLINES.ASSET_HYPERLINK]: (node, children) => {
      let asset = resolveEntry(node, graphLinks)

      return (
        <>
          {asset?.fields && (
            <a
              href={asset.fields.url}
              size="md"
            >
              {children}
            </a>
          )}
        </>
      )
    },
    [INLINES.ENTRY_HYPERLINK]: (node, children) => {
      let entry = resolveEntry(node)
      const contentType = entry.sys?.contentType?.sys?.id
      const linkSlug = entry.fields?.slug

      if (contentType === 'pageSimple') {
        return (
          <a href={linkSlug === 'news' ? '/news' : `/news/${linkSlug}`}>
            {children}
          </a>
        )
      }
      return <a href={`/${linkSlug}`}>{children}</a>
    },
  },
})

export default renderRichText
